Learn R Programming

datadogr (version 0.1.2)

k9_get_events: Get Events

Description

This end point allows you to query for event details.

Usage

k9_get_events(event_id = NULL, start = NULL, end = NULL,
  priority = NULL, sources = NULL, tags = NULL, .split_request = TRUE)

Arguments

event_id

Event ID.

start

POSIX timestamp.

end

POSIX timestamp.

priority

Priority of events. NULL, "low" or "normal".

sources

Sources of events. A character vector or a single comma-separated character.

tags

Tags of events. A named list or a single comma-separated character.

.split_request

if TRUE, automatically split the request when the target period is longer than a day

See Also

http://docs.datadoghq.com/api/?lang=console#events

Examples

Run this code
# NOT RUN {
# by default get all events happend from an hour ago
k9_get_events()

# get all events happend in this week
k9_get_events(start = Sys.Date() - 7, end = Sys.Date())

# specify an event by ID
k9_get_events(event_id = "112233445566")

# specify tag
k9_get_events(tags = list(role = "db"))
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab