Learn R Programming

datadogr (version 0.1.2)

k9_list_metrics: Get List Of Active Metrics

Description

Get the list of actively reporting metrics from a given time until now.

Usage

k9_list_metrics(from = NULL)

Arguments

from

seconds since the unix epoch

Examples

Run this code
# NOT RUN {
# by default, list all metrics available since 1 hour ago
k9_list_metrics()

# if from argument is provided, this tries to get active metrics from the time
k9_list_metrics(Sys.Date() - 1)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab