This end point allows you to post time-series data that can be graphed on Datadog<U+2019>s dashboards or queried from any time period.
k9_post_metric(metric, metric_type, value, tags = list(), interval = NULL)the name of the time series
type of your metric either: gauge, rate, or count. Optional, default=gauge
the numeric value to post
a list of tags associated with the metric.
if the type of the metric is rate or count, define the corresponding interval. Optional, default=None
The Datadog API uses resource-oriented URLs, uses status codes to indicate the success or failure of requests and returns JSON from all requests. With this method you can post counters, gauges to measure the value of a particular thing over time and rates that represent the derivative of a metric, it<U+2019>s the value variation of a metric on a defined time interval.
http://docs.datadoghq.com/api/?lang=console#metrics http://docs.datadoghq.com/graphing/ https://docs.datadoghq.com/developers/metrics/#metric-types